
# coding: utf-8

# # Plot a fit over a density plot
# Use the ``densityreg`` plot method to combine fits and their raw data.
# 
# This example uses artifical data to show you the capabilities of the ``densityreg`` plot method.

# In[ ]:


import numpy as np
import xarray as xr
import psyplot.project as psy
get_ipython().run_line_magic('matplotlib', 'inline')
get_ipython().run_line_magic('config', 'InlineBackend.close_figures = False')


# First we define our data which comes from multiple realizations of the underlying equation ``sin(x)``

# In[ ]:


all_x = []
all_y = []
for i in range(30):
    deviation = np.abs(np.random.normal())
    all_x.append(np.linspace(-np.pi - deviation, np.pi + deviation))
    all_y.append(np.sin(all_x[-1]) + np.random.normal(scale=0.5, size=all_x[-1].size))
x = np.concatenate(all_x)
y = np.concatenate(all_y)
ds = xr.Dataset({'x': xr.Variable(('experiment', ), x),
                 'y': xr.Variable(('experiment', ), y)})
ds


# This dataset now contains the two variables ``x`` and ``y``. A scatter plot of the data looks like

# In[ ]:


psy.plot.lineplot(ds, name='y', coord='x', marker='o', linewidth=0)


# However, it is hard to see how many data points there are shown. Therefore this is a good candidate for a
# ``density`` plot:

# In[ ]:


psy.plot.density(ds, name='y', coord='x', cmap='Reds', bins=50, density='kde',
                 clabel='Kernel density')


# The ``densityreg`` plot method combines this plot with a fit through the data

# In[ ]:


psy.close('all')
psy.plot.densityreg(ds, name='y', coord='x', cmap='Reds', bins=50, density='kde', 
                    clabel='Kernel density',
                    color='Blues_r', fit=lambda x, a: np.sin(a * x), 
                    legendlabels='$\sin (%(a)1.2f * %(xname)s$)')


# In[ ]:


psy.close('all')

